4.3 (2025-02-28)
----------------

- Bump krcg (V5 Hecata)


4.2 (2024-09-15)
----------------

- Fix syntax error bug preventing the bot to start


4.1 (2024-09-15)
----------------

- New rulings format (KRCG v4)


4.0 (2023-08-11)
----------------

- Using hikari
- The card images are now correctly displayed again
- New button "make public"
- New buttons to list cards mentionned in text and rulings
- History management ("come back" button)


3.4 (2023-07-28)
----------------

- Bump KRCG (3.0)
- Bump Discord lib discord-py-interactions (4.4.1)


3.3 (2022-11-14)
----------------

- Fix embed border color for powers and convictions
- Bump KRCG (2.30)

3.2 (2022-08-25)
----------------

- Fix message update for private messages


3.1 (2022-08-25)
----------------

- Fix message ephemerality by default


3.0 (2022-08-25)
----------------

- Switch to slash commands
- Now works in threads and in the text chat in vocal channels
- Add buttons to switch vampires between base / advanced / evolution
- Use disciplines and icons emojis if available on the server


2.9 (2022-01-17)
----------------

- Bump KRCG (2.21)


2.8 (2021-12-05)
----------------

- Update to V5 Anarch (krcg 2.20)


2.7 (2021-08-27)
----------------

- Bump KRCG version


2.6 (2021-07-22)
----------------

- Bump KRCG version


2.5 (2021-07-09)
----------------

- Improve logging


2.4 (2021-07-08)
----------------

- Bump KRCG version

2.3 (2021-07-08)
----------------

- Bump KRCG version


2.2 (2020-12-30)
----------------

- Bump KRCG version


2.1 (2020-12-21)
----------------

- Fix python 3.7


2.0 (2020-12-21)
----------------

- Release 2.0, for alignement wiht KRCG package (no change)


1.11 (2020-12-21)
-----------------

- Minor fixes (doc, packaging)


2.0 (2020-12-20)
----------------
